@@ -5,10 +5,10 @@ mod random_bool;
 pub use random_bool::random_bool;
 
 mod random_str;
-pub use random_str::random_str;
+pub use random_str::{random_str, random_str_rg};
 
 mod swap;
 pub use swap::swap;
 
-#[cfg(feature = "asyn")]
-pub mod asyn;
+#[cfg(feature = "async")]
+pub mod futures;
